@@ -1,5 +1,6 @@
-from corpusflow.io import read_markdown
-from corpusflow.core import Document, DocumentPattern
+from tokenizer_tools.tagset.offset.analysis.read_markdown import read_markdown
+from tokenizer_tools.tagset.offset.document import Document
+from tokenizer_tools.tagset.offset.analysis.document_pattern import DocumentPattern
 
 
 def test_read_markdown(datadir):
@@ -11,9 +12,9 @@ def test_read_markdown(datadir):
     # check if str match
     expected_str_snippet = [
         "this is [#1](order) corpus. xxx. yyy.",
-        "this is <entity> corpus",
+        "this is `entity` corpus",
         "this is #3 corpus. xxx. yyy.",
-        "this is #4 corpus"
+        "this is #4 corpus",
     ]
 
     result_str = [str(i) for i in raw_result]
@@ -23,12 +24,7 @@ def test_read_markdown(datadir):
         assert expected_doc_str in result_doc_str
 
     # check if type match
-    expected_type = [
-        Document,
-        DocumentPattern,
-        Document,
-        Document
-    ]
+    expected_type = [Document, DocumentPattern, Document, Document]
 
     for i, result_doc_obj in enumerate(raw_result):
         expected_doc_type = expected_type[i]
