@@ -5,8 +5,9 @@ from sklearn.model_selection import train_test_split
 from fuzzywuzzy import process
 
 from tokenizer_tools.conllz.reader import read_conllx
+from tokenizer_tools.tagset.NER.BILUO import BILUOEncoderDecoder
 from tokenizer_tools.conllz.writer import write_conllx
-from tokenizer_tools.converter.conllz_to_offset import conllz_to_offset
+from tokenizer_tools.converter.conllx_to_offset import conllx_to_offset
 from tokenizer_tools.converter.offset_to_sentence import offset_to_sentence
 from tokenizer_tools.tagset.offset.corpus_statistics import CorpusStatistics
 from tokenizer_tools.tagset.offset.document import Document
@@ -35,7 +36,7 @@ class Corpus(List[Document]):
 
         offset_data_list = []
         for sentence in sentence_list:
-            offset_data, result = conllz_to_offset(sentence)
+            offset_data, result = conllx_to_offset(sentence)
 
             offset_data_list.append(offset_data)
 
@@ -61,7 +62,9 @@ class Corpus(List[Document]):
         for document in self:
             document.set_compare_way(compare_way)
 
-    def set_document_compare_method(self, compare_method: Callable[["Sequence", "Sequence"], bool]):
+    def set_document_compare_method(
+        self, compare_method: Callable[["Sequence", "Sequence"], bool]
+    ):
         for document in self:
             document.set_compare_method(compare_method)
 
@@ -161,3 +164,20 @@ class Corpus(List[Document]):
         result = process.extract(query, choices, limit=limit)
 
         return result
+
+    def annotation_tags(self, scheme=None) -> List[str]:
+        if scheme is not None:
+            raise ValueError("scheme argument is not supported yet")
+
+        entities = {span.entity for doc in self for span in doc.span_set}
+
+        tags = {
+            i for entity in entities for i in BILUOEncoderDecoder(entity).all_tag_set()
+        }
+
+        # for better human reading, sort it
+        tags_except_oscar = tags - {"O"}
+
+        sorted_tags = ["O"] + sorted(tags_except_oscar)
+
+        return sorted_tags
